==> kubernetes-model-networking-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressClassParametersReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IngressClassParametersReferenceBuilder extends IngressClassParametersReferenceFluentImpl<IngressClassParametersReferenceBuilder> implements VisitableBuilder<IngressClassParametersReference,IngressClassParametersReferenceBuilder>{
  public IngressClassParametersReferenceBuilder() {
    this(false);
  }
  public IngressClassParametersReferenceBuilder(Boolean validationEnabled) {
    this(new IngressClassParametersReference(), validationEnabled);
  }
  public IngressClassParametersReferenceBuilder(IngressClassParametersReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressClassParametersReferenceBuilder(IngressClassParametersReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IngressClassParametersReference(), validationEnabled);
  }
  public IngressClassParametersReferenceBuilder(IngressClassParametersReferenceFluent<?> fluent,IngressClassParametersReference instance) {
    this(fluent, instance, false);
  }
  public IngressClassParametersReferenceBuilder(IngressClassParametersReferenceFluent<?> fluent,IngressClassParametersReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiGroup(instance.getApiGroup());
      fluent.withKind(instance.getKind());
      fluent.withName(instance.getName());
      fluent.withNamespace(instance.getNamespace());
      fluent.withScope(instance.getScope());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IngressClassParametersReferenceBuilder(IngressClassParametersReference instance) {
    this(instance,false);
  }
  public IngressClassParametersReferenceBuilder(IngressClassParametersReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiGroup(instance.getApiGroup());
      this.withKind(instance.getKind());
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
      this.withScope(instance.getScope());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  IngressClassParametersReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public IngressClassParametersReference build() {
    IngressClassParametersReference buildable = new IngressClassParametersReference(fluent.getApiGroup(),fluent.getKind(),fluent.getName(),fluent.getNamespace(),fluent.getScope());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-networking-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressClassParametersReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IngressClassParametersReferenceBuilder extends IngressClassParametersReferenceFluent<IngressClassParametersReferenceBuilder> implements VisitableBuilder<IngressClassParametersReference,IngressClassParametersReferenceBuilder>{
  public IngressClassParametersReferenceBuilder() {
    this(false);
  }
  public IngressClassParametersReferenceBuilder(Boolean validationEnabled) {
    this(new IngressClassParametersReference(), validationEnabled);
  }
  public IngressClassParametersReferenceBuilder(IngressClassParametersReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressClassParametersReferenceBuilder(IngressClassParametersReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IngressClassParametersReference(), validationEnabled);
  }
  public IngressClassParametersReferenceBuilder(IngressClassParametersReferenceFluent<?> fluent,IngressClassParametersReference instance) {
    this(fluent, instance, false);
  }
  public IngressClassParametersReferenceBuilder(IngressClassParametersReferenceFluent<?> fluent,IngressClassParametersReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new IngressClassParametersReference());

    if (instance != null) {
      fluent.withApiGroup(instance.getApiGroup());
      fluent.withKind(instance.getKind());
      fluent.withName(instance.getName());
      fluent.withNamespace(instance.getNamespace());
      fluent.withScope(instance.getScope());
      fluent.withApiGroup(instance.getApiGroup());
      fluent.withKind(instance.getKind());
      fluent.withName(instance.getName());
      fluent.withNamespace(instance.getNamespace());
      fluent.withScope(instance.getScope());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IngressClassParametersReferenceBuilder(IngressClassParametersReference instance) {
    this(instance,false);
  }
  public IngressClassParametersReferenceBuilder(IngressClassParametersReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new IngressClassParametersReference());

    if (instance != null) {
      this.withApiGroup(instance.getApiGroup());
      this.withKind(instance.getKind());
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
      this.withScope(instance.getScope());
      this.withApiGroup(instance.getApiGroup());
      this.withKind(instance.getKind());
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
      this.withScope(instance.getScope());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  IngressClassParametersReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public IngressClassParametersReference build() {
    IngressClassParametersReference buildable = new IngressClassParametersReference(fluent.getApiGroup(),fluent.getKind(),fluent.getName(),fluent.getNamespace(),fluent.getScope());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
